@@ -28,7 +28,6 @@
 #include <kio/fileundomanager.h>
 #include <ksortablelist.h>
 #include <kxmlguiwindow.h>
-#include <KActionMenu>
 #include <KIcon>
 
 #include <QList>
@@ -41,6 +40,7 @@ class DolphinApplication;
 class DolphinSettingsDialog;
 class DolphinViewContainer;
 class DolphinRemoteEncoding;
+class DolphinTabPage;
 class KAction;
 class KFileItem;
 class KFileItemList;
@@ -89,13 +89,6 @@ public:
      */
     void openFiles(const QList<KUrl>& files);
 
-    /**
-     * Returns true, if the main window contains two instances
-     * of a view container. The active view constainer can be
-     * accessed by DolphinMainWindow::activeViewContainer().
-     */
-    bool isSplit() const;
-
     /**
      * Returns the 'Create New...' sub menu which also can be shared
      * with other menus (e. g. a context menu).
@@ -156,6 +149,11 @@ signals:
      */
     void settingsChanged();
 
+    /**
+     * Is emitted when a tab has been closed.
+     */
+    void rememberClosedTab(const KUrl& primaryUrl, const KUrl& secondaryUrl);
+
 protected:
     /** @see QWidget::showEvent() */
     virtual void showEvent(QShowEvent* event);
@@ -192,9 +190,6 @@ private slots:
      */
     void slotUndoAvailable(bool available);
 
-    /** Invoked when an action in the recent tabs menu is clicked. */
-    void restoreClosedTab(QAction* action);
-
     /** Sets the text of the 'Undo' menu action to \a text. */
     void slotUndoTextChanged(const QString& text);
 
@@ -352,15 +347,16 @@ private slots:
     void openNewTab();
 
     /**
-     * Opens a new tab in the background showing the URL \a url.
+     * Opens a new tab in the background showing the URL \a primaryUrl and the
+     * optional URL \a secondaryUrl.
      */
-    void openNewTab(const KUrl& url);
+    void openNewTab(const KUrl& primaryUrl, const KUrl& secondaryUrl = KUrl());
 
     /**
-     * Opens a new tab showing the URL \a url and activates
-     * the tab.
+     * Opens a new tab showing the  URL \a primaryUrl and the optional URL
+     * \a secondaryUrl and activates the tab.
      */
-    void openNewActivatedTab(const KUrl& url);
+    void openNewActivatedTab(const KUrl& primaryUrl, const KUrl& secondaryUrl = KUrl());
 
     void activateNextTab();
 
@@ -376,9 +372,6 @@ private slots:
      */
     void openInNewWindow();
 
-    /** Toggles the active view if two views are shown within the main window. */
-    void toggleActiveView();
-
     /**
      * Indicates in the statusbar that the execution of the command \a command
      * has been finished.
@@ -473,6 +466,8 @@ private slots:
      */
     void slotPlaceActivated(const KUrl& url);
 
+    void activeViewChanged();
+
 private:
     /**
      * Activates the given view, which means that
@@ -482,11 +477,6 @@ private:
      */
     void setActiveViewContainer(DolphinViewContainer* view);
 
-    /**
-     * Creates a view container and does a default initialization.
-     */
-    DolphinViewContainer* createViewContainer(const KUrl& url, QWidget* parent);
-
     void setupActions();
     void setupDockWidgets();
     void updateEditActions();
@@ -503,11 +493,6 @@ private:
      */
     bool addActionToMenu(QAction* action, KMenu* menu);
 
-    /**
-     * Adds the tab[\a index] to the closed tab menu's list of actions.
-     */
-    void rememberClosedTab(int index);
-
     /**
      * Connects the signals from the created DolphinView with
      * the DolphinViewContainer \a container with the corresponding slots of
@@ -527,17 +512,9 @@ private:
     /** Returns the name of the tab for the URL \a url. */
     QString tabName(const KUrl& url) const;
 
+
     bool isKompareInstalled() const;
 
-    void createSecondaryView(int tabIndex);
-
-    /**
-     * Helper method for saveProperties() and readProperties(): Returns
-     * the property string for a tab with the index \a tabIndex and
-     * the property \a property.
-     */
-    QString tabProperty(const QString& property, int tabIndex) const;
-
     /**
      * Sets the window caption to url.fileName() if this is non-empty,
      * "/" if the URL is "file:///", and url.protocol() otherwise.
@@ -572,24 +549,13 @@ private:
     };
 
     KNewFileMenu* m_newFileMenu;
-    KActionMenu* m_recentTabsMenu;
     KTabBar* m_tabBar;
     DolphinViewContainer* m_activeViewContainer;
     QVBoxLayout* m_centralWidgetLayout;
     int m_id;
 
-    // Members for the tab-handling:
-    struct ViewTab
-    {
-        ViewTab() : isPrimaryViewActive(true), wasActive(false), primaryView(0), secondaryView(0), splitter(0) {}
-        bool isPrimaryViewActive;
-        bool wasActive;
-        DolphinViewContainer* primaryView;
-        DolphinViewContainer* secondaryView;
-        QSplitter* splitter;
-    };
     int m_tabIndex;
-    QList<ViewTab> m_viewTab;
+    QList<DolphinTabPage*> m_viewTab;
 
     DolphinViewActionHandler* m_actionHandler;
     DolphinRemoteEncoding* m_remoteEncoding;
@@ -607,11 +573,6 @@ inline DolphinViewContainer* DolphinMainWindow::activeViewContainer() const
     return m_activeViewContainer;
 }
 
-inline bool DolphinMainWindow::isSplit() const
-{
-    return m_viewTab[m_tabIndex].secondaryView != 0;
-}
-
 inline KNewFileMenu* DolphinMainWindow::newFileMenu() const
 {
     return m_newFileMenu;
