@@ -27,10 +27,7 @@
 #include "dolphin_iconsmodesettings.h"
 #include "viewpropsprogressinfo.h"
 
-#include <config-nepomuk.h>
-#ifdef HAVE_NEPOMUK
-#include <Nepomuk2/ResourceManager>
-#endif
+#include <config-baloo.h>
 
 #include <KComponentData>
 #include <KLocale>
