@@ -1031,8 +1031,17 @@ QPair<bool, QString> KonqOperations::pasteInfo(const KUrl& targetUrl)
     QClipboard* clipboard = QApplication::clipboard();
     const QMimeData* mimeData = clipboard->mimeData();
 
-    const bool canPasteData = KIO::canPasteMimeSource(mimeData);
-    KUrl::List urls = KUrl::List::fromMimeData(mimeData);
+    bool canPasteData = false;
+    KUrl::List urls;
+
+    // mimeData can be 0 according to https://bugs.kde.org/show_bug.cgi?id=335053
+    if (mimeData) {
+        canPasteData = KIO::canPasteMimeSource(mimeData);
+        urls = KUrl::List::fromMimeData(mimeData);
+    } else {
+        kWarning(1203) << "QApplication::clipboard()->mimeData() is 0!";
+    }
+
     if (!urls.isEmpty() || canPasteData) {
         // disable the paste action if no writing is supported
         KFileItem item(KFileItem::Unknown, KFileItem::Unknown, targetUrl);
